@@ -7,6 +7,7 @@ from ocrd_utils import (
     get_local_filename,
     setOverrideLogLevel,
     parse_json_string_or_file,
+    set_json_key_value_overrides
 )
 
 from ocrd_utils import getLogger
@@ -22,10 +23,21 @@ loglevel_option = click.option('-l', '--log-level', help="Log level",
                                type=click.Choice(['OFF', 'ERROR', 'WARN', 'INFO', 'DEBUG', 'TRACE']),
                                default=None, callback=_set_root_logger_version)
 
+def _handle_param_option(ctx, param, value):
+    return parse_json_string_or_file(*list(value))
+
 parameter_option = click.option('-p', '--parameter',
                                 help="Parameters, either JSON string or path to JSON file",
-                                default='{}',
-                                callback=lambda ctx, param, value: parse_json_string_or_file(value))
+                                multiple=True,
+                                default=['{}'],
+                                callback=_handle_param_option)
+
+parameter_override_option = click.option('-P', '--parameter-override',
+                                help="Parameter override",
+                                nargs=2,
+                                multiple=True,
+                                callback=lambda ctx, param, kv: kv)
+                                # callback=lambda ctx, param, kv: {kv[0]: kv[1]})
 
 def ocrd_cli_wrap_processor(
     processorClass,
@@ -50,6 +62,10 @@ def ocrd_cli_wrap_processor(
         LOG.error(msg)
         raise Exception(msg)
     else:
+        # LOG.info('kwargs=%s' % kwargs)
+        # Merge parameter overrides and parameters
+        if 'parameter_override' in kwargs:
+            set_json_key_value_overrides(kwargs['parameter'], *kwargs['parameter_override'])
         if is_local_filename(mets) and not isfile(get_local_filename(mets)):
             msg = "File does not exist: %s" % mets
             LOG.error(msg)
@@ -109,6 +125,7 @@ def ocrd_cli_options(f):
         click.option('-g', '--page-id', help="ID(s) of the pages to process"),
         click.option('--overwrite', help="Overwrite the output file group or a page range (--page-id)", is_flag=True, default=False),
         parameter_option,
+        parameter_override_option,
         click.option('-J', '--dump-json', help="Dump tool description as JSON and exit", is_flag=True, default=False),
         loglevel_option,
         click.option('-V', '--version', help="Show version", is_flag=True, default=False),
